Struct WpLinuxDrmSyncobjSurfaceV1
pub struct WpLinuxDrmSyncobjSurfaceV1 { /* private fields */ }wayland and Linux only.Expand description
per-surface explicit synchronization
This object is an add-on interface for wl_surface to enable explicit synchronization.
Each surface can be associated with only one object of this interface at any time.
Explicit synchronization is guaranteed to be supported for buffers created with any version of the linux-dmabuf protocol. Compositors are free to support explicit synchronization for additional buffer types. If at surface commit time the attached buffer does not support explicit synchronization, an unsupported_buffer error is raised.
As long as the wp_linux_drm_syncobj_surface_v1 object is alive, the compositor may ignore implicit synchronization for buffers attached and committed to the wl_surface. The delivery of wl_buffer.release events for buffers attached to the surface becomes undefined.
Clients must set both acquire and release points if and only if a non-null buffer is attached in the same surface commit. See the no_buffer, no_acquire_point and no_release_point protocol errors.
If at surface commit time the acquire and release DRM syncobj timelines are identical, the acquire point value must be strictly less than the release point value, or else the conflicting_points protocol error is raised.
This interface has no events.
Implementations
impl WpLinuxDrmSyncobjSurfaceV1
impl WpLinuxDrmSyncobjSurfaceV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the surface synchronization object
Destroy this surface synchronization object.
Any timeline point set by this object with set_acquire_point or set_release_point since the last commit may be discarded by the compositor. Any timeline point set by this object before the last commit will not be affected.
pub fn set_acquire_point(
&self,
timeline: &WpLinuxDrmSyncobjTimelineV1,
point_hi: u32,
point_lo: u32,
)
pub fn set_acquire_point( &self, timeline: &WpLinuxDrmSyncobjTimelineV1, point_hi: u32, point_lo: u32, )
set the acquire timeline point
Set the timeline point that must be signalled before the compositor may sample from the buffer attached with wl_surface.attach.
The 64-bit unsigned value combined from point_hi and point_lo is the point value.
The acquire point is double-buffered state, and will be applied on the next wl_surface.commit request for the associated surface. Thus, it applies only to the buffer that is attached to the surface at commit time.
If an acquire point has already been attached during the same commit cycle, the new point replaces the old one.
If the associated wl_surface was destroyed, a no_surface error is raised.
If at surface commit time there is a pending acquire timeline point set but no pending buffer attached, a no_buffer error is raised. If at surface commit time there is a pending buffer attached but no pending acquire timeline point set, the no_acquire_point protocol error is raised.
pub fn set_release_point(
&self,
timeline: &WpLinuxDrmSyncobjTimelineV1,
point_hi: u32,
point_lo: u32,
)
pub fn set_release_point( &self, timeline: &WpLinuxDrmSyncobjTimelineV1, point_hi: u32, point_lo: u32, )
set the release timeline point
Set the timeline point that must be signalled by the compositor when it has finished its usage of the buffer attached with wl_surface.attach for the relevant commit.
Once the timeline point is signaled, and assuming the associated buffer is not pending release from other wl_surface.commit requests, no additional explicit or implicit synchronization with the compositor is required to safely re-use the buffer.
Note that clients cannot rely on the release point being always signaled after the acquire point: compositors may release buffers without ever reading from them. In addition, the compositor may use different presentation paths for different commits, which may have different release behavior. As a result, the compositor may signal the release points in a different order than the client committed them.
Because signaling a timeline point also signals every previous point, it is generally not safe to use the same timeline object for the release points of multiple buffers. The out-of-order signaling described above may lead to a release point being signaled before the compositor has finished reading. To avoid this, it is strongly recommended that each buffer should use a separate timeline for its release points.
The 64-bit unsigned value combined from point_hi and point_lo is the point value.
The release point is double-buffered state, and will be applied on the next wl_surface.commit request for the associated surface. Thus, it applies only to the buffer that is attached to the surface at commit time.
If a release point has already been attached during the same commit cycle, the new point replaces the old one.
If the associated wl_surface was destroyed, a no_surface error is raised.
If at surface commit time there is a pending release timeline point set but no pending buffer attached, a no_buffer error is raised. If at surface commit time there is a pending buffer attached but no pending release timeline point set, the no_release_point protocol error is raised.